summaryrefslogtreecommitdiffstats
path: root/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
diff options
context:
space:
mode:
Diffstat (limited to 'libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c')
-rw-r--r--libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c b/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
index 518dc20b1..ebae5ea38 100644
--- a/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
+++ b/libkdenetwork/libgpgme-copy/assuan/assuan-pipe-connect.c
@@ -325,7 +325,7 @@ pipe_connect_unix (assuan_context_t *ctx,
}
errno = 0;
- /* We store our parents pid in the environment so that the
+ /* We store our tqparents pid in the environment so that the
execed assuan server is able to read the actual pid of the
client. The server can't use getppid because it might have
been double forked before the assuan server has been
@@ -337,7 +337,7 @@ pipe_connect_unix (assuan_context_t *ctx,
unsetenv ("_assuan_connection_fd");
execv (name, (char *const *) argv);
/* oops - use the pipe to tell the parent about it */
snprintf (errbuf, sizeof(errbuf)-1,
"ERR %d can't exec `%s': %.50s\n",
_assuan_error (ASSUAN_Problem_Starting_Server),
@@ -493,7 +493,7 @@ socketpair_connect (assuan_context_t *ctx,
}
errno = 0;
- /* We store our parents pid in the environment so that the
+ /* We store our tqparents pid in the environment so that the
execed assuan server is able to read the actual pid of the
client. The server can't use getppid becuase it might have
been double forked before the assuan server has been
@@ -519,7 +519,7 @@ socketpair_connect (assuan_context_t *ctx,
}
execv (name, (char *const *) argv);
/* oops - use the pipe to tell the parent about it */
snprintf (errbuf, sizeof(errbuf)-1,
"ERR %d can't exec `%s': %.50s\n",
_assuan_error (ASSUAN_Problem_Starting_Server),
@@ -865,7 +865,7 @@ assuan_pipe_connect2 (assuan_context_t *ctx,
If NAME as well as ARGV are NULL, no exec is done but the same
process is continued. However all file descriptors are closed and
some special environment variables are set. To let the caller
- detect whether the child or the parent continues, the child returns
+ detect whether the child or the tqparent continues, the child returns
a CTX of NULL. */
assuan_error_t
assuan_pipe_connect_ext (assuan_context_t *ctx,
@@ -337,7 +337,7 @@ pipe_connect_unix (assuan_context_t *ctx,
unsetenv ("_assuan_connection_fd");
execv (name, (char *const *) argv);
- /* oops - use the pipe to tell the parent about it */
+ /* oops - use the pipe to tell the tqparent about it */
snprintf (errbuf, sizeof(errbuf)-1,
"ERR %d can't exec `%s': %.50s\n",
@@ -519,7 +519,7 @@ socketpair_connect (assuan_context_t *ctx,
}
execv (name, (char *const *) argv);
- /* oops - use the pipe to tell the parent about it */
+ /* oops - use the pipe to tell the tqparent about it */
snprintf (errbuf, sizeof(errbuf)-1,
"ERR %d can't exec `%s': %.50s\n",